==> dome-1.23.tar.bz2: dome-1.23/dome.h <==
#ifndef _DOME_H
#define _DOME_H

#include "dome_device.h"
#include "modes.h"

struct Dome_CMD {
    std::string cfgfile;
    bool test_mode;
    bool back_mode;
    bool auto_init;
};

class Dome {
    std::map<std::string, Mode*, Cmpi> tableMode;
    Config Domecfg;
    Device deviceDome;
    Close  closeDome;
    Open   openDome;
    Mode*  the;
    static Dome* self_ptr;
    const static int initLifeSec;
    const static int parkLifeSec;
    static pthread_t thread_id;
    Dome();
   ~Dome() {} // std::cerr << "Destructor Dome\n";}
public:
    class Lock { // for self_ptr
        Lock(const Lock&);
        Lock& operator=(const Lock&);
        static pthread_mutex_t mtx;
    public:
        Lock() {pthread_mutex_lock(&mtx);}
        ~Lock() {pthread_mutex_unlock(&mtx);}
    };
    static Dome_CMD cmd;
    static void create();
    static void destroy();
    static void runproc() { device_ptr()->run(); }
    static Dome* device_ptr();
    static bool exist() { Lock lock; return self_ptr != 0 ;}
    static int initLife() { return initLifeSec; }
    static int parkLife() { return parkLifeSec; }
    void run() { thread_id = pthread_self(); the->action(); }
    void set( const std::string&, const std::string& );
    std::string get( const std::string& );
    int  specify( const std::vector<std::string>& );
    int  stop( const std::vector<std::string>& );
    int  quit( const std::vector<std::string>& ){ return 0;}
    static bool works() { return true; }
private:
    void setAction( const std::string & );
    void setLimit( const std::string & );
    void setPower( const std::string & );
    void setLight( const std::string & );
    std::string status();
    std::string position();
    std::string limit();
    std::string power_stat();
    std::string light_stat();
};


#endif

==> dome-2.01.tar.bz2: dome-2.01/dome.h <==
#ifndef _DOME_H
#define _DOME_H

#include "dome.h"
#include "modes.h"

struct Dome_CMD {
    std::string cfgfile;
    bool test_mode;
    bool back_mode;
    bool auto_init;
};

class Dome {
    std::map<std::string, Mode*, Cmpi> tableMode;
    std::map<std::string, Mode*, Cmpi> tableAxes;
    std::map<std::string, Mode*, Cmpi> tableDome;
    Config Domecfg;
    Device deviceDome;
    Close  closeDome;
    Open   openDome;
    Move   moveDome;
    Mode*  the;
    std::map<std::string, int, Cmpi> tableTube;
    int  side;
    static Dome* self_ptr;
    const static int initLifeSec;
    const static int parkLifeSec;
    static pthread_t thread_id;
    Dome();
   ~Dome() {} // std::cerr << "Destructor Mokko\n";}
public:
    class Lock { // for self_ptr
        Lock(const Lock&);
        Lock& operator=(const Lock&);
        static pthread_mutex_t mtx;
    public:
        Lock() {pthread_mutex_lock(&mtx);}
        ~Lock() {pthread_mutex_unlock(&mtx);}
    };
    static Dome_CMD cmd;
    static void create();
    static void destroy();
    static void runproc() { device_ptr()->run(); }
    static Dome* device_ptr();
    static bool exist() { Lock lock; return self_ptr != 0 ;}
    static int initLife() { return initLifeSec; }
    static int parkLife() { return parkLifeSec; }
    void run() { thread_id = pthread_self(); the->action(); }
    void set( const std::string&, const std::string& );
    std::string get( const std::string& );
    int  specify( const std::vector<std::string>& );
    int  stop( const std::vector<std::string>& );
    int  quit( const std::vector<std::string>& ){ return 0;}
    static bool works() { return true; }
private:
    double defineAction( const std::string & );
    void setDomeAction( const std::string & );
    void setSideAaction( const std::string & );
    void setSideBaction( const std::string & );
    std::string dome_status();
    std::string side_position();
};


#endif
